@@ -24,7 +24,8 @@ def format_datetime(dt):
         pattern = re.compile('\\d{2}-\\d{2}')
         pattern2 = re.compile('\\d{4}-\\d{2}-\\d{2}')
         pattern3 = re.compile('\\d{2}:\\d{2}')
-        pattern4 = re.compile('\\d{2}月\\d{2}日 \\d{2}:\\d{2}')
+        pattern4 = re.compile('\\d{2}月\\d{2}日\\s\\d{2}:\\d{2}')
+        pattern5 = re.compile('(\\d{4}年\\d{2}月\\d{2}日\\s\\d{2}:\\d{2})')
         if '分钟前' in dt:
             # m = int(dt.split('分钟')[0].strip())
             mpattern = re.compile('(\\d+)分钟前')
@@ -64,6 +65,10 @@ def format_datetime(dt):
             strdate = str(datetime.datetime.now().year) + '-' + dt
             strdate = strdate.replace('月', '-')
             ret = strdate.replace('日', '')
+        elif re.match(pattern5, dt):
+            strdate = dt.replace('年', '-')
+            strdate = strdate.replace('月', '-')
+            ret = strdate.replace('日', '')
         elif '+0800' in dt:
             dtformat = datetime.datetime.strptime(dt, '%a %b %d %H:%M:%S +0800 %Y')
             ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
